@@ -72,7 +72,7 @@ class BertOnce(nn.Module):
                 predicted_index = torch.argmax(predictions[start]).item()
                 predicted_token = self.tokenizer.convert_ids_to_tokens([predicted_index])
                 logit_prob = softmax(predictions[start]).data.tolist()
-                prob_result = {self.tokenizer.ids_to_tokens[id]: prob for id, prob in enumerate(logit_prob)}
+                prob_result = {self.tokenizer.decode([id]): prob for id, prob in enumerate(logit_prob)}
                 prob_result = sorted(prob_result.items(), key=lambda x: x[1], reverse=True)
                 output_prob_dict.append(prob_result)
                 if tok_sep(self.tokenizer) in predicted_token:
