@@ -33,9 +33,9 @@ class loadColTaggerDataset(data.Dataset):
                 feature = get_feature_from_data(tokenizer, labels, input, target, maxlen=maxlen)
                 if len(feature['input']) == len(feature['target']) <= tokenizer.max_model_input_sizes[pretrained]:
                     samples.append(feature)
-                if cache:
-                    with open(cache_path, 'wb') as cf:
-                        pickle.dump({'samples': samples, 'labels': labels}, cf)
+            if cache:
+                with open(cache_path, 'wb') as cf:
+                    pickle.dump({'samples': samples, 'labels': labels}, cf)
         self.sample = samples
         self.label = labels
 
@@ -64,9 +64,9 @@ class loadRowTaggerDataset(data.Dataset):
                 feature = get_feature_from_data(tokenizer, labels, input, target, maxlen=maxlen)
                 if len(feature['input']) == len(feature['target']) <= tokenizer.max_model_input_sizes[pretrained]:
                     samples.append(feature)
-                if cache:
-                    with open(cache_path, 'wb') as cf:
-                        pickle.dump({'samples': samples, 'labels': labels}, cf)
+            if cache:
+                with open(cache_path, 'wb') as cf:
+                    pickle.dump({'samples': samples, 'labels': labels}, cf)
         self.sample = samples
         self.label = labels
 
@@ -133,7 +133,8 @@ def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, sep
 
     pos = 1  # cls as start 0
     for i in input:
-        for _ in range(len([x for x in tokenizer.tokenize(i) if x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
+        for _ in range(len([x for x in tokenizer.tokenize(i) if
+                            x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
             if _ < 1:
                 mapping_index.append({'char': i, 'pos': pos})
             pos += 1
@@ -143,7 +144,8 @@ def get_feature_from_data(tokenizer, labels, input, target=None, maxlen=512, sep
         target_token = []
 
         for i, t in zip(input, target):
-            for _ in range(len([x for x in tokenizer.tokenize(i) if x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
+            for _ in range(len([x for x in tokenizer.tokenize(i) if
+                                x not in tokenizer.all_special_tokens or x == tokenizer.unk_token])):
                 target_token += [labels.index(t)]
 
         target_id = [labels.index("O")] + target_token + [labels.index("O")]
